@@ -15,6 +15,9 @@ Tests, tests, tests.........
 
 import os
 import sqlalchemy
+import sqlalchemy.orm
+import unittest
+import tempfile
 
 from sqlalchemy import MetaData, Integer, String, Column, Table
 from sqlalchemy.ext.declarative import declarative_base
@@ -28,15 +31,18 @@ from z3c.sqlalchemy.interfaces import ISQLAlchemyWrapper, IModel
 from z3c.sqlalchemy.postgres import ZopePostgresWrapper
 from z3c.sqlalchemy.mapper import MappedClassBase
 from z3c.sqlalchemy import createSAWrapper, Model, registerSAWrapper, getSAWrapper
-from Testing.ZopeTestCase import ZopeTestCase
 
 
-class WrapperTests(ZopeTestCase):
+class WrapperTests(unittest.TestCase):
 
     def setUp(self):
 
-        self.dsn = os.environ.get('TEST_DSN', 'sqlite:///test')
-        wrapper = createSAWrapper(self.dsn)
+        self.dsn = os.environ.get('TEST_DSN')
+        self.tempfile = None
+        if not self.dsn:
+            self.tempfile = tempfile.mktemp()
+            self.dsn = 'sqlite:///%s' % self.tempfile
+        self.db = wrapper = createSAWrapper(self.dsn)
         metadata = MetaData(bind=wrapper.engine)
 
         users = Table('users', metadata,
@@ -46,12 +52,17 @@ class WrapperTests(ZopeTestCase):
 
         skill = Table('skills', metadata,
                       Column('user_id', Integer, primary_key=True),
-                      Column('user_id', Integer),
                       Column('name', String(255)))
 
-        metadata.drop_all()
         metadata.create_all()
 
+    def tearDown(self):
+        if self.tempfile:
+            os.remove(self.tempfile)
+        else:
+            metadata = MetaData(bind=self.db.engine)
+            metadata.drop_all()
+
     def testIFaceZopePostgres(self):
         verifyClass(ISQLAlchemyWrapper , ZopePostgresWrapper)
 
@@ -69,11 +80,11 @@ class WrapperTests(ZopeTestCase):
         rows = session.query(User).all()
         self.assertEqual(len(rows), 0)
 
-        session.save(User(id=1, firstname='udo', lastname='juergens'))
-        session.save(User(id=2, firstname='heino', lastname='n/a'))
+        session.add(User(id=1, firstname='udo', lastname='juergens'))
+        session.add(User(id=2, firstname='heino', lastname='n/a'))
         session.flush()
 
-        rows = session.query(User).order_by(User.c.id).all()
+        rows = session.query(User).order_by(User.id).all()
         self.assertEqual(len(rows), 2)
         row1 = rows[0]
         d = row1.asDict()
@@ -92,6 +103,16 @@ class WrapperTests(ZopeTestCase):
         User = db.getMapper('users')
         self.assertEqual(User, myUser)
 
+    def testCustomMapperRegister(self):
+        mytable = Table(
+            'mytable', self.db.metadata,
+            Column('id', Integer, primary_key=True),
+        )
+        class MyClass(object):
+            pass
+        mapper = sqlalchemy.orm.mapper(MyClass, mytable)
+        self.db.registerMapper(mapper, 'mymapper')
+
 
 #    def testCustomMapperClassWithWrongType(self):
 #
@@ -134,7 +155,7 @@ class WrapperTests(ZopeTestCase):
         wrapper2 = getSAWrapper('test.wrapper1')
         self.assertEqual(wrapper, wrapper2)
 
-    
+
     def testWrapperRegistrationFailing(self):
         wrapper = createSAWrapper(self.dsn)
         self.assertRaises(ValueError, getSAWrapper, 'test.wrapperNonExistant')
@@ -151,28 +172,6 @@ class WrapperTests(ZopeTestCase):
         wrapper2 = getSAWrapper('test.wrapper3')
         self.assertEqual(wrapper, wrapper2)
 
-        
-    def testXXMapperGetMapper(self):
-        def getModel(md):
-
-            model = Model()
-            model.add('users', table=sqlalchemy.Table('users', md, autoload=True), relations=('skills',))
-            model.add('skills', table=sqlalchemy.Table('skills', 
-                                                       md, 
-                                                       sqlalchemy.ForeignKeyConstraint(('user_id',), ('users.id',)),
-                                                       autoload=True, 
-                                                       ))
-            return model
-
-        db = createSAWrapper(self.dsn, model=getModel)
-        User = db.getMapper('users')
-        session = db.session
-        session.save(User(id=1,firstname='foo', lastname='bar'))
-        session.flush()
-        user = session.query(User).filter_by(firstname='foo')[0]
-        Skill = user.getMapper('skills')
-        user.skills.append(Skill(id=1, name='Zope'))
-        session.flush()
 
     def testCheckConnection(self):
         """ Check access to low-level connection """
@@ -185,15 +184,14 @@ class WrapperTests(ZopeTestCase):
 
     def testConnectionPlusSession(self):
         """ Check access to low-level connection """
-        db = createSAWrapper(self.dsn)
 
-        User = db.getMapper('users')
-        session = db.session
-        session.save(User(id=1, firstname='udo', lastname='juergens'))
-        session.save(User(id=2, firstname='heino', lastname='n/a'))
+        User = self.db.getMapper('users')
+        session = self.db.session
+        session.add(User(id=1, firstname='udo', lastname='juergens'))
+        session.add(User(id=2, firstname='heino', lastname='n/a'))
         session.flush()
 
-        conn = db.connection               
+        conn = self.db.connection
         cursor = conn.cursor()
         cursor.execute('select * from users')
         rows = cursor.fetchall()
@@ -215,8 +213,8 @@ class WrapperTests(ZopeTestCase):
 
         Base.metadata.create_all(db._engine)
 
-        session.save(Foo(id=1, name='Andreas Jung'))
-        session.save(Foo(id=2, name='Peter Becker'))
+        session.add(Foo(id=1, name='Andreas Jung'))
+        session.add(Foo(id=2, name='Peter Becker'))
         session.flush()
 
         rows = session.query(Foo).all()
@@ -243,8 +241,8 @@ class WrapperTests(ZopeTestCase):
         session = db.session
         Foo = db.getMapper('foo')
 
-        session.save(Foo(id=1, name='Andreas Jung'))
-        session.save(Foo(id=2, name='Peter Becker'))
+        session.add(Foo(id=1, name='Andreas Jung'))
+        session.add(Foo(id=2, name='Peter Becker'))
         session.flush()
 
         rows = session.query(Foo).all()
